/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Leo Merholz
 *      Pascal Schärli
 *
 *      Co-authors:
 *      ...
 */

#include "PacmanHUDinfo.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "util/Convert.h"

namespace orxonox
{
    RegisterClass(PacmanHUDinfo);

    PacmanHUDinfo::PacmanHUDinfo(Context* context) : OverlayText(context)
    {
        RegisterObject(PacmanHUDinfo);

        this->PacmanGame = nullptr;
        this->bShowPoints_ = false;
        this->bShowMessage_ = false;
        this->messageID = 0;
    }

    void PacmanHUDinfo::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(PacmanHUDinfo, XMLPort, xmlelement, mode);

        XMLPortParam(PacmanHUDinfo, "showpoints",    setShowPoints,    getShowPoints,    xmlelement, mode).defaultValues(false);
        XMLPortParam(PacmanHUDinfo, "showmessage",   setShowMessage,   getShowMessage,   xmlelement, mode).defaultValues(false);
        XMLPortParam(PacmanHUDinfo, "messageID",     setMessageID,     getMessageID,     xmlelement, mode).defaultValues(0);
       
    
    }

    void PacmanHUDinfo::tick(float dt)
    {
        SUPER(PacmanHUDinfo, tick, dt);

        if (this->PacmanGame)
        {
            if(not this->PacmanGame->isDead()){
                if(this->bShowPoints_){
                    const std::string& points = "Score: "+multi_cast<std::string>(this->PacmanGame->getPoints());
                    setTextSize(0.04);
                    this->setCaption(points);
                }
                else if(this->bShowMessage_){
                    setTextSize(0);
                }
            }
            else{
                if(this->bShowPoints_){
                    setTextSize(0);
                }
                else if(this->bShowMessage_){
                    if(this->PacmanGame->firstGame){
                        if(messageID==3){
                            setTextSize(0.05);
                            this->setCaption("First click, then press space to start");
                        }
                    }
                    else{
                        std::string message;
                        setTextSize(0.05);
                        switch(messageID){
                            case 0:
                                message = "Game Over";
                                setTextSize(0.1);
                                this->setCaption(message);
                            break;
                            case 1:
                                message = this->PacmanGame->sDeathMessage;
                            break;
                            case 2:
                                message = "Your Score: "+multi_cast<std::string>(this->PacmanGame->getPoints())+
                                                        "  Local High Score: "+multi_cast<std::string>(Highscore::getInstance().getHighestScoreOfGame("Flappy Orx"));
                            break;
                            case 3:
                                time_t time = this->PacmanGame->getPlayer()->timeUntilRespawn();
                                if(time<=0)
                                    message = "Press space to restart.";
                                else
                                    message = "Please wait "+multi_cast<std::string>(time)+" seconds.";
                            break;
                        }
                        this->setCaption(message);
                    }
                }
            }   
        }
    }

    void PacmanHUDinfo::changedOwner()
    {
        SUPER(PacmanHUDinfo, changedOwner);

        if (this->getOwner() && this->getOwner()->getGametype())
        {
            this->PacmanGame = orxonox_cast<Pacman*>(this->getOwner()->getGametype());
        }
        else
        {
            this->PacmanGame = nullptr;
        }
    }
}